pub const fn to_array<const N: usize>(s: &str) -> [u8; N]Expand description
Copy a string slice into a fixed-size byte array at compile time, leaving space for a null terminator.
pub const fn to_array<const N: usize>(s: &str) -> [u8; N]Copy a string slice into a fixed-size byte array at compile time, leaving space for a null terminator.