pin_init_ffi

Macro pin_init_ffi 

macro_rules! pin_init_ffi {
    ($ffi_fn:expr) => { ... };
}
A helper macro to initialize a pinned object in-place using a raw FFI constructor.

This generates a PinInit block that passes a type-cast pointer of the allocated slot to the FFI function, returning Ok(()).