Deferred

Struct Deferred 

pub struct Deferred<F: FnOnce()> { /* private fields */ }
A guard that executes an action when dropped, unless cancelled.

This provides equivalent functionality to C++ fit::deferred_action and fit::defer.

Implementations

Source

impl<F: FnOnce()> Deferred<F>

pub const fn new(action: F) -> Self

Creates a new Deferred action that will run when dropped.

pub fn cancel(&mut self)

Cancels the deferred action so that it will not run upon drop.

pub fn call(&mut self)

Executes the deferred action immediately and cancels it.