pub struct Opaque<T>(/* private fields */);Expand description
A wrapper for types that are opaque to Rust.
This is used to wrap C++ objects that Rust should not access directly. It provides a raw pointer to the inner data for use in FFI.
Implementations