pub type OpaqueBytes<const SIZE: usize> = Opaque<[u8; SIZE]>;Expand description
A generic, safe opaque storage container with exact const size constraints.
This integrates with Opaque<T> to guarantee the Rust compiler knows the underlying memory
is interior-mutable (via UnsafeCell) and potentially uninitialized (via MaybeUninit).
Aliased Type
pub struct OpaqueBytes<const SIZE: usize>(/* private fields */);